Modules
- atomic
- builder
- cast
- combination
- combiner
- comparator
- error
- expander
- flags
- resolution
- shared
- A collection of shared, static, and lazily-initialized
TAtomictypes. - template
- union
Enums
- TypeRef
- A reference to a type in the type system, which can be either a union or an atomic type.
Traits
- TType
- A trait to be implemented by all types in the type system.
Functions
- add_
optional_ union_ type - add_
optional_ union_ type_ rc - Reference-counted variant of
add_optional_union_type. - add_
union_ type - combine_
optional_ union_ types - combine_
union_ types - combine_
union_ types_ rc - Reference-counted variant of
combine_union_types. - get_
array_ parameters - get_
array_ value_ parameter - get_
arraykey - get_
bool - get_
callable_ string - get_
class_ string - get_
closed_ resource - get_
empty - The
emptytype: every value for which PHP’sempty()returns true, i.e.null|0|0.0|'0'|''|false|array{}. - get_
empty_ keyed_ array - get_
empty_ scalar - The
empty-scalartype: every scalar for which PHP’sempty()returns true, i.e.0|0.0|'0'|''|false. - get_
empty_ string - get_
false - get_
float - get_int
- get_
int_ or_ float - get_
int_ or_ string - get_
int_ range - get_
isset_ from_ mixed_ mixed - get_
iterable_ parameters - get_
iterable_ value_ parameter - get_
keyed_ array - get_
list - get_
literal_ float - get_
literal_ int - get_
literal_ string - get_
lowercase_ string - get_
minus_ one_ int - Returns a zero-allocation
TUnionfor the integer literal-1. - get_
mixed - get_
mixed_ callable - get_
mixed_ closure - get_
mixed_ iterable - get_
mixed_ keyed_ array - get_
mixed_ list - get_
mixed_ maybe_ from_ loop - get_
named_ object - get_
negative_ int - get_
never - get_
non_ empty_ list - get_
non_ empty_ lowercase_ string - get_
non_ empty_ string - get_
non_ empty_ unspecified_ literal_ string - get_
non_ empty_ uppercase_ string - get_
non_ negative_ int - get_
non_ positive_ int - get_
non_ zero_ int - get_
null - get_
nullable_ float - get_
nullable_ int - get_
nullable_ object - get_
nullable_ scalar - get_
nullable_ string - get_
numeric - get_
numeric_ string - get_
object - get_
one_ int - Returns a zero-allocation
TUnionfor the integer literal1. - get_
open_ resource - get_
placeholder - get_
positive_ int - get_
resource - get_
scalar - get_
signum_ result - Returns a zero-allocation
TUnionfor the type-1|0|1. - get_
specialized_ template_ type - Resolves a generic template from an ancestor class in the context of a descendant class.
- get_
string - get_
string_ with_ props - Returns a zero-allocation
TUnionfor astringwith the specified properties. - get_
true - get_
truthy_ mixed - get_
truthy_ string - get_
undefined_ null - get_
union_ from_ integer - Creates a
TUnionfrom aTInteger, using a canonical static type where possible. - get_
unspecified_ literal_ float - get_
unspecified_ literal_ int - get_
unspecified_ literal_ string - get_
uppercase_ string - get_
void - get_
zero_ int - Returns a zero-allocation
TUnionfor the integer literal0. - intersect_
union_ types - wrap_
atomic