pub struct UnionFlags(/* private fields */);Expand description
Flags representing various properties of a type union.
This replaces 9 individual boolean fields with a compact 16-bit representation, reducing memory usage from 9 bytes to 2 bytes per TUnion instance.
Implementations
Sourceimpl UnionFlags
impl UnionFlags
Sourcepub const HAD_TEMPLATE: UnionFlags
pub const HAD_TEMPLATE: UnionFlags
Indicates the union had a template type at some point.
Sourcepub const BY_REFERENCE: UnionFlags
pub const BY_REFERENCE: UnionFlags
Indicates the value is passed by reference.
Sourcepub const REFERENCE_FREE: UnionFlags
pub const REFERENCE_FREE: UnionFlags
Indicates no references exist to this type.
Sourcepub const POSSIBLY_UNDEFINED_FROM_TRY: UnionFlags
pub const POSSIBLY_UNDEFINED_FROM_TRY: UnionFlags
Indicates the type may be undefined due to a try block.
Sourcepub const POSSIBLY_UNDEFINED: UnionFlags
pub const POSSIBLY_UNDEFINED: UnionFlags
Indicates the type may be undefined.
Sourcepub const IGNORE_NULLABLE_ISSUES: UnionFlags
pub const IGNORE_NULLABLE_ISSUES: UnionFlags
Indicates nullable issues should be ignored for this type.
Sourcepub const IGNORE_FALSABLE_ISSUES: UnionFlags
pub const IGNORE_FALSABLE_ISSUES: UnionFlags
Indicates falsable issues should be ignored for this type.
Sourcepub const FROM_TEMPLATE_DEFAULT: UnionFlags
pub const FROM_TEMPLATE_DEFAULT: UnionFlags
Indicates the type came from a template default value.
Sourcepub const POPULATED: UnionFlags
pub const POPULATED: UnionFlags
Indicates the type has been populated with codebase information.
Sourcepub const NULLSAFE_NULL: UnionFlags
pub const NULLSAFE_NULL: UnionFlags
Indicates the null in this union came from nullsafe short-circuit.
Sourceimpl UnionFlags
impl UnionFlags
pub const fn empty() -> Self
pub const fn insert(&mut self, flag: UnionFlags)
pub const fn set(&mut self, flag: UnionFlags, value: bool)
pub const fn contains(self, flag: UnionFlags) -> bool
pub const fn intersects(self, other: UnionFlags) -> bool
pub const fn union(&self, other: UnionFlags) -> UnionFlags
pub const fn intersection(&self, other: UnionFlags) -> UnionFlags