Module template

Module template 

Modules

bounds
Helpers for resolving the most specific type a template parameter has been bound to during inference.
definition_type_replacer
inferred_type_replacer
variance

Structs

GenericTemplate
Represents a template parameter definition with its source and constraint type.
TemplateBound
TemplateResult